From 410c99d5713db62d6cfcbf2b973ea43bd1b5eff7 Mon Sep 17 00:00:00 2001
From: Kris Jusiak
Date: Sun, 10 Nov 2024 14:02:47 +0000
Subject: [PATCH] :arrow_up: v2.1.1
---
CMakeLists.txt | 2 +-
README.md | 6 +++---
include/boost/ut.hpp | 6 +++---
3 files changed, 7 insertions(+), 7 deletions(-)
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 835f4e1d..d9491e88 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -7,7 +7,7 @@
cmake_minimum_required(VERSION 3.21...3.25)
project(
ut
- VERSION 2.1.0
+ VERSION 2.1.1
LANGUAGES CXX
)
diff --git a/README.md b/README.md
index 8f930ec2..047b226c 100644
--- a/README.md
+++ b/README.md
@@ -190,7 +190,7 @@ target_link_libraries(my_test PRIVATE Boost::ut)
> [Optional] [Conan](https://conan.io) integration
The [boost-ext-ut](https://conan.io/center/boost-ext-ut) package is available from [Conan Center](https://conan.io/center/).
-Just include it in your project's Conanfile with `boost-ext-ut/2.1.0`.
+Just include it in your project's Conanfile with `boost-ext-ut/2.1.1`.
@@ -1244,7 +1244,7 @@ int main() {
```cpp
export module boost.ut; /// __cpp_modules
-namespace boost::inline ext::ut::inline v2_1_0 {
+namespace boost::inline ext::ut::inline v2_1_1 {
/**
* Represents test suite object
*/
@@ -1605,7 +1605,7 @@ namespace boost::inline ext::ut::inline v2_1_0 {
| Option | Description | Example |
|-|-|-|
-| `BOOST_UT_VERSION` | Current version | `2'1'0` |
+| `BOOST_UT_VERSION` | Current version | `2'1'1` |
diff --git a/include/boost/ut.hpp b/include/boost/ut.hpp
index 83446fa9..6059292d 100644
--- a/include/boost/ut.hpp
+++ b/include/boost/ut.hpp
@@ -57,7 +57,7 @@ export import std;
#elif not defined(__cpp_static_assert)
#error "[Boost::ext].UT requires support for static assert";
#else
-#define BOOST_UT_VERSION 2'1'0
+#define BOOST_UT_VERSION 2'1'1
#if defined(__has_builtin) and defined(__GNUC__) and (__GNUC__ < 10) and \
not defined(__clang__)
@@ -109,7 +109,7 @@ struct unique_name_for_auto_detect_prefix_and_suffix_length_0123456789_struct_ {
};
BOOST_UT_EXPORT
-namespace boost::inline ext::ut::inline v2_1_0 {
+namespace boost::inline ext::ut::inline v2_1_1 {
namespace utility {
template
class function;
@@ -3324,7 +3324,7 @@ using operators::operator not;
using operators::operator|;
using operators::operator/;
using operators::operator>>;
-} // namespace boost::inline ext::ut::inline v2_1_0
+} // namespace boost::inline ext::ut::inline v2_1_1
#if (defined(__GNUC__) || defined(__clang__) || defined(__INTEL_COMPILER)) && \
!defined(__EMSCRIPTEN__)